@@ -1,4 +1,3 @@
-import asyncio
 try:
     import requests
 except ImportError:  # pragma: no cover
@@ -10,21 +9,27 @@ except ImportError:  # pragma: no cover
 
 
 class BaseHttpTransport:
-    def __init__(self, url):
+    def __init__(self, url, verb="POST"):
         self._validate()
         self.url = url
+        self.verb = verb
         self.session = None
+        #TODO: basic auth, custom headers, tls ?
 
     def _validate(self):  # pragma: no cover
         pass
 
+    def prepare_data(self, iterable):
+        data = b"\n".join(iterable)
+        if data.endswith(b"\n\n"):  # pragma: no cover
+            return data
+        to_pad = 1 if data[-1] == ord(b"\n") else 2
+        return data.ljust(len(data) + to_pad, b"\n")
+
     def push_all_sync(self):
         raise NotImplementedError("brave proposal")
 
 
-# TODO: configurable push formats ?
-
-
 class SyncHttpTransport(BaseHttpTransport):
     def _validate(self):
         if requests is None:
@@ -37,8 +42,8 @@ class SyncHttpTransport(BaseHttpTransport):
         self.session.close()
 
     def push_all(self, iterable):
-        data = b"\n".join(iterable)
-        self.session.post(self.url, data=data)
+        data = self.prepare_data(iterable)
+        self.session.request(self.verb, self.url, data=data)
 
 
 class AioHttpTransport(BaseHttpTransport):
@@ -53,6 +58,6 @@ class AioHttpTransport(BaseHttpTransport):
         await self.session.close()
 
     async def push_all(self, iterable):
-        data = b"\n".join(iterable)
-        async with self.session.post(self.url, data=data) as _:
+        data = self.prepare_data(iterable)
+        async with self.session.request(self.verb, self.url, data=data) as _:
             pass
\ No newline at end of file
